@@ -18,6 +18,7 @@ You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
+@todo Figure out how to integrate with the Maemo contacts app
 @todo Look into an actor system
 @bug Session timeouts are bad, possible solutions:
 	@li For every X minutes, if logged in, attempt login
@@ -150,10 +151,7 @@ class Dialcentral(object):
 		else:
 			pass # warnings.warn("No Hildon", UserWarning, 2)
 
-		if hildon is not None:
-			self._window.set_title("Keypad")
-		else:
-			self._window.set_title("%s - Keypad" % constants.__pretty_app_name__)
+		self._window.set_title("%s" % constants.__pretty_app_name__)
 
 		callbackMapping = {
 			"on_dialpad_quit": self._on_close,
@@ -164,6 +162,13 @@ class Dialcentral(object):
 		self._window.set_default_size(800, 300)
 		self._window.show_all()
 
+		self._loginSink = gtk_toolbox.threaded_stage(
+			gtk_toolbox.comap(
+				self.attempt_login,
+				gtk_toolbox.null_sink(),
+			)
+		)
+
 		backgroundSetup = threading.Thread(target=self._idle_setup)
 		backgroundSetup.setDaemon(True)
 		backgroundSetup.start()
@@ -313,7 +318,7 @@ class Dialcentral(object):
 			with gtk_toolbox.gtk_lock():
 				self.load_settings(config)
 
-			gtk_toolbox.asynchronous_gtk_message(self._spawn_attempt_login)(2)
+			self._spawn_attempt_login(2)
 		except StandardError, e:
 			warnings.warn(e.message, UserWarning, 2)
 		except BaseException, e:
@@ -354,9 +359,7 @@ class Dialcentral(object):
 				self._errorDisplay.push_exception(e)
 
 	def _spawn_attempt_login(self, *args):
-		backgroundLogin = threading.Thread(target=self.attempt_login, args=args)
-		backgroundLogin.setDaemon(True)
-		backgroundLogin.start()
+		self._loginSink.send(args)
 
 	def refresh_session(self):
 		"""
@@ -634,18 +637,12 @@ class Dialcentral(object):
 		elif page_num == self.ACCOUNT_TAB:
 			self._accountViews[self._selectedBackendId].update()
 
-		tabTitle = self._notebook.get_tab_label(self._notebook.get_nth_page(page_num)).get_text()
-		if hildon is not None:
-			self._window.set_title(tabTitle)
-		else:
-			self._window.set_title("%s - %s" % (constants.__pretty_app_name__, tabTitle))
-
 	def _on_sms_clicked(self, number, message):
 		assert number
 		assert message
 		try:
 			loggedIn = self._phoneBackends[self._selectedBackendId].is_authed()
-		except RuntimeError, e:
+		except StandardError, e:
 			loggedIn = False
 			self._errorDisplay.push_exception(e)
 			return
@@ -660,7 +657,7 @@ class Dialcentral(object):
 		try:
 			self._phoneBackends[self._selectedBackendId].send_sms(number, message)
 			dialed = True
-		except RuntimeError, e:
+		except StandardError, e:
 			self._errorDisplay.push_exception(e)
 		except ValueError, e:
 			self._errorDisplay.push_exception(e)
@@ -669,7 +666,7 @@ class Dialcentral(object):
 		assert number
 		try:
 			loggedIn = self._phoneBackends[self._selectedBackendId].is_authed()
-		except RuntimeError, e:
+		except StandardError, e:
 			loggedIn = False
 			self._errorDisplay.push_exception(e)
 			return
@@ -685,7 +682,7 @@ class Dialcentral(object):
 			assert self._phoneBackends[self._selectedBackendId].get_callback_number() != ""
 			self._phoneBackends[self._selectedBackendId].dial(number)
 			dialed = True
-		except RuntimeError, e:
+		except StandardError, e:
 			self._errorDisplay.push_exception(e)
 		except ValueError, e:
 			self._errorDisplay.push_exception(e)
