@@ -610,7 +610,7 @@ class AccountInfo(object):
 		self._callbackList.clear()
 		try:
 			callbackNumbers = self._backend.get_callback_numbers()
-		except RuntimeError, e:
+		except StandardError, e:
 			self._errorDisplay.push_exception(e)
 			self._isPopulated = False
 			return
@@ -629,16 +629,31 @@ class AccountInfo(object):
 			if not self._backend.is_valid_syntax(number):
 				self._errorDisplay.push_message("%s is not a valid callback number" % number)
 			elif number == self._backend.get_callback_number():
-				warnings.warn("Callback number already is %s" % self._backend.get_callback_number(), UserWarning, 2)
+				warnings.warn(
+					"Callback number already is %s" % (
+						self._backend.get_callback_number(),
+					),
+					UserWarning,
+					2
+				)
 			else:
 				self._backend.set_callback_number(number)
-				warnings.warn("Callback number set to %s" % self._backend.get_callback_number(), UserWarning, 2)
-		except RuntimeError, e:
+				assert make_ugly(number) == make_ugly(self._backend.get_callback_number()), "Callback number should be %s but instead is %s" % (
+					make_pretty(number), make_pretty(self._backend.get_callback_number())
+				)
+				warnings.warn(
+					"Callback number set to %s" % (
+						self._backend.get_callback_number(),
+					),
+					UserWarning, 2
+				)
+		except StandardError, e:
 			self._errorDisplay.push_exception(e)
 
 	def _on_callbackentry_changed(self, *args):
 		text = self.get_selected_callback_number()
-		self._set_callback_number(text)
+		number = make_ugly(text)
+		self._set_callback_number(number)
 
 
 class RecentCallsView(object):
@@ -685,6 +700,13 @@ class RecentCallsView(object):
 		self._window = gtk_toolbox.find_parent_window(self._recentview)
 		self._phoneTypeSelector = PhoneTypeSelector(widgetTree, self._backend)
 
+		self._updateSink = gtk_toolbox.threaded_stage(
+			gtk_toolbox.comap(
+				self._idly_populate_recentview,
+				gtk_toolbox.null_sink(),
+			)
+		)
+
 	def enable(self):
 		assert self._backend.is_authed()
 		self._recentview.set_model(self._recentmodel)
@@ -716,9 +738,7 @@ class RecentCallsView(object):
 	def update(self, force = False):
 		if not force and self._isPopulated:
 			return
-		backgroundPopulate = threading.Thread(target=self._idly_populate_recentview)
-		backgroundPopulate.setDaemon(True)
-		backgroundPopulate.start()
+		self._updateSink.send(())
 
 	def clear(self):
 		self._isPopulated = False
@@ -743,7 +763,7 @@ class RecentCallsView(object):
 
 		try:
 			recentItems = self._backend.get_recent()
-		except RuntimeError, e:
+		except StandardError, e:
 			self._errorDisplay.push_exception_with_lock(e)
 			self._isPopulated = False
 			recentItems = []
@@ -827,6 +847,13 @@ class MessagesView(object):
 		self._window = gtk_toolbox.find_parent_window(self._messageview)
 		self._phoneTypeSelector = PhoneTypeSelector(widgetTree, self._backend)
 
+		self._updateSink = gtk_toolbox.threaded_stage(
+			gtk_toolbox.comap(
+				self._idly_populate_messageview,
+				gtk_toolbox.null_sink(),
+			)
+		)
+
 	def enable(self):
 		assert self._backend.is_authed()
 		self._messageview.set_model(self._messagemodel)
@@ -858,9 +885,7 @@ class MessagesView(object):
 	def update(self, force = False):
 		if not force and self._isPopulated:
 			return
-		backgroundPopulate = threading.Thread(target=self._idly_populate_messageview)
-		backgroundPopulate.setDaemon(True)
-		backgroundPopulate.start()
+		self._updateSink.send(())
 
 	def clear(self):
 		self._isPopulated = False
@@ -885,7 +910,7 @@ class MessagesView(object):
 
 		try:
 			messageItems = self._backend.get_messages()
-		except RuntimeError, e:
+		except StandardError, e:
 			self._errorDisplay.push_exception_with_lock(e)
 			self._isPopulated = False
 			messageItems = []
@@ -957,6 +982,13 @@ class ContactsView(object):
 		self._window = gtk_toolbox.find_parent_window(self._contactsview)
 		self._phoneTypeSelector = PhoneTypeSelector(widgetTree, self._backend)
 
+		self._updateSink = gtk_toolbox.threaded_stage(
+			gtk_toolbox.comap(
+				self._idly_populate_contactsview,
+				gtk_toolbox.null_sink(),
+			)
+		)
+
 	def enable(self):
 		assert self._backend.is_authed()
 
@@ -1019,15 +1051,11 @@ class ContactsView(object):
 	def update(self, force = False):
 		if not force and self._isPopulated:
 			return
-		backgroundPopulate = threading.Thread(target=self._idly_populate_contactsview)
-		backgroundPopulate.setDaemon(True)
-		backgroundPopulate.start()
+		self._updateSink.send(())
 
 	def clear(self):
 		self._isPopulated = False
 		self._contactsmodel.clear()
-
-	def clear_caches(self):
 		for factory in self._addressBookFactories:
 			factory.clear_caches()
 		self._addressBook.clear_caches()
@@ -1057,22 +1085,24 @@ class ContactsView(object):
 
 		# completely disable updating the treeview while we populate the data
 		self._contactsview.freeze_child_notify()
-		self._contactsview.set_model(None)
-
-		addressBook = self._addressBook
 		try:
-			contacts = addressBook.get_contacts()
-		except RuntimeError, e:
-			contacts = []
-			self._isPopulated = False
-			self._errorDisplay.push_exception_with_lock(e)
-		for contactId, contactName in contacts:
-			contactType = (addressBook.contact_source_short_name(contactId), )
-			self._contactsmodel.append(contactType + (contactName, "", contactId) + ("", ))
+			self._contactsview.set_model(None)
 
-		# restart the treeview data rendering
-		self._contactsview.set_model(self._contactsmodel)
-		self._contactsview.thaw_child_notify()
+			addressBook = self._addressBook
+			try:
+				contacts = addressBook.get_contacts()
+			except StandardError, e:
+				contacts = []
+				self._isPopulated = False
+				self._errorDisplay.push_exception_with_lock(e)
+			for contactId, contactName in contacts:
+				contactType = (addressBook.contact_source_short_name(contactId), )
+				self._contactsmodel.append(contactType + (contactName, "", contactId) + ("", ))
+
+			# restart the treeview data rendering
+			self._contactsview.set_model(self._contactsmodel)
+		finally:
+			self._contactsview.thaw_child_notify()
 		return False
 
 	def _on_addressbook_combo_changed(self, *args, **kwds):
@@ -1092,7 +1122,7 @@ class ContactsView(object):
 		contactName = self._contactsmodel.get_value(itr, 1)
 		try:
 			contactDetails = self._addressBook.get_contact_details(contactId)
-		except RuntimeError, e:
+		except StandardError, e:
 			contactDetails = []
 			self._errorDisplay.push_exception(e)
 		contactPhoneNumbers = [phoneNumber for phoneNumber in contactDetails]
